# Conditionals to help breaking eclipse <-> xbean dependency cycle
# when bootstrapping for new architectures
%bcond_without equinox
%bcond_without spring

Name:           xbean
Version:        4.4
Release:        %mkrel 2
Group:          Development/Java
Summary:        Java plugin based web server
License:        ASL 2.0
URL:            http://geronimo.apache.org/xbean/
BuildArch:      noarch

Source0:        http://repo2.maven.org/maven2/org/apache/%{name}/%{name}/%{version}/%{name}-%{version}-source-release.zip

# Fix dependency on xbean-asm4-shaded to original objectweb-asm
Patch0:         0001-Unshade-ASM.patch
# Compatibility with Eclipse Luna (rhbz#1087461)
Patch1:         0002-Port-to-Eclipse-Luna-OSGi.patch
Patch2:         0003-Port-to-QDox-2.0.patch

BuildRequires:  java-devel
BuildRequires:  apache-commons-beanutils
BuildRequires:  apache-commons-logging
BuildRequires:  objectweb-asm
BuildRequires:  ant
BuildRequires:  qdox
BuildRequires:  slf4j
BuildRequires:  maven-local
BuildRequires:  maven-plugin-bundle
BuildRequires:  maven-antrun-plugin
BuildRequires:  maven-compiler-plugin
BuildRequires:  maven-dependency-plugin
BuildRequires:  maven-install-plugin
BuildRequires:  maven-javadoc-plugin
BuildRequires:  maven-resources-plugin
BuildRequires:  maven-surefire-plugin
BuildRequires:  maven-site-plugin
BuildRequires:  maven-shade-plugin
%if %{with equinox}
BuildRequires:  eclipse-equinox-osgi
%else
BuildRequires:  felix-framework
%endif
%if %{with spring}
BuildRequires:  apache-commons-jexl
BuildRequires:  aries-blueprint
# test deps
BuildRequires:  cglib
BuildRequires:  felix-osgi-compendium
BuildRequires:  felix-osgi-core
BuildRequires:  geronimo-annotation
BuildRequires:  pax-logging

BuildRequires:  maven-archiver
BuildRequires:  maven-plugin-plugin
BuildRequires:  maven-project
BuildRequires:  plexus-archiver
BuildRequires:  plexus-utils
BuildRequires:  springframework
BuildRequires:  springframework-beans
BuildRequires:  springframework-context
BuildRequires:  springframework-web
%endif

%description
The goal of XBean project is to create a plugin based server
analogous to Eclipse being a plugin based IDE. XBean will be able to
discover, download and install server plugins from an Internet based
repository. In addition, we include support for multiple IoC systems,
support for running with no IoC system, JMX without JMX code,
lifecycle and class loader management, and a rock solid Spring
integration.

%if %{with spring}
# For now blueprint module fails to compile. Disable it.
%if 0
%package        blueprint
Summary:        Schema-driven namespace handler for Apache Aries Blueprint

%description    blueprint
This package provides %{summary}.
%endif

%package        classloader
Summary:        A flexibie multi-parent classloader

%description    classloader
This package provides %{summary}.

%package        spring
Summary:        Schema-driven namespace handler for spring contexts
Requires:       %{name} = %{version}-%{release}

%description    spring
This package provides %{summary}.

%package        -n maven-%{name}-plugin
Summary:        XBean plugin for Apache Maven

%description    -n maven-%{name}-plugin
This package provides %{summary}.
%endif

%package        javadoc
Summary:        API documentation for %{name}

%description    javadoc
This package provides %{summary}.

%prep
%setup -q
# build failing on this due to doxia-sitetools problems
rm src/site/site.xml

%patch0 -p1
%if %{with equinox}
%patch1 -p1
%endif
%patch2 -p1

%pom_remove_parent
%pom_remove_dep mx4j:mx4j

%pom_remove_dep -r :xbean-asm-util
%pom_remove_dep -r :xbean-asm5-shaded
%pom_remove_dep -r :xbean-finder-shaded
%pom_disable_module xbean-asm-util
%pom_disable_module xbean-asm5-shaded
%pom_disable_module xbean-finder-shaded

# Prevent modules depending on springframework from building.
%if %{without spring}
   %pom_remove_dep org.springframework:
   #%%pom_disable_module xbean-blueprint
   %pom_disable_module xbean-classloader
   %pom_disable_module xbean-spring
   %pom_disable_module maven-xbean-plugin
%else
   %mvn_package :xbean-classloader classloader
   %mvn_package :xbean-spring spring
   %mvn_package :maven-xbean-plugin maven-xbean-plugin
%endif
# blueprint FTBFS, disable for now
%pom_disable_module xbean-blueprint

%if %{without equinox}
  # Replace Eclipse Equinox OSGi dependency with Apeche Felix
  rm -rf xbean-bundleutils/src/main/java/org/apache/xbean/osgi/bundle/util/equinox/
  %pom_remove_dep org.eclipse:osgi xbean-bundleutils
  %pom_add_dep org.apache.felix:org.apache.felix.framework xbean-bundleutils
%endif

# maven-xbean-plugin invocation makes no sense as there are no namespaces
%pom_remove_plugin :maven-xbean-plugin xbean-classloader

# As auditing tool RAT is useful for upstream only.
%pom_remove_plugin :apache-rat-plugin

# disable copy of internal aries-blueprint
sed -i "s|<Private-Package>|<!--Private-Package>|" xbean-blueprint/pom.xml
sed -i "s|</Private-Package>|</Private-Package-->|" xbean-blueprint/pom.xml

%build
%mvn_build -f

%install
%mvn_install

%files -f .mfiles
%doc LICENSE NOTICE
%dir %{_javadir}/%{name}

%if %{with spring}
%if 0
%files blueprint -f .mfiles-blueprint
%doc LICENSE NOTICE %{name}-blueprint/target/restaurant.xsd*
%endif

%files classloader -f .mfiles-classloader
%doc LICENSE NOTICE

%files spring -f .mfiles-spring
%doc LICENSE NOTICE

%files -n maven-%{name}-plugin -f .mfiles-maven-%{name}-plugin
%doc LICENSE NOTICE
%endif

%files javadoc -f .mfiles-javadoc
%doc LICENSE NOTICE



%changelog
* Wed Feb 24 2016 neoclust <neoclust> 4.4-2.mga6
+ Revision: 978221
- First rebuild of the java stack
- sync package xbean with fedora

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Fri Feb 20 2015 daviddavid <daviddavid> 3.17-5.mga5
+ Revision: 816122
- rebuild for new jruby, yecht and nailgun
- add missing BuildRequires on options and jffi-native

* Fri Jan 30 2015 daviddavid <daviddavid> 3.17-4.mga5
+ Revision: 812719
- add missing BuildRequires on jboss-el-2.2-api
- add missing BuildRequires on jboss-servlet-3.0-api
- fix Group

* Sat Dec 27 2014 pterjan <pterjan> 3.17-3.mga5
+ Revision: 806417
- Clean rebuild
- Rebuild with spring
- Sync with Fedora 21 (update to 3.17)

  + luigiwalser <luigiwalser>
    - build without spring

  + sander85 <sander85>
    - Well, try to drop xbean-spring as well as it depends on springframework-web which will be dropped
    - Try to drop maven-xbean-plugin as it depends on dropped xbean-spring

* Wed Oct 15 2014 umeabot <umeabot> 3.16-5.mga5
+ Revision: 741613
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

  + dmorgan <dmorgan>
    - Disable P0: Try to fix clash

* Tue Dec 31 2013 dmorgan <dmorgan> 3.16-2.mga4
+ Revision: 563672
- Rebuild against fixed springframework

* Mon Dec 30 2013 dmorgan <dmorgan> 3.16-1.mga4
+ Revision: 563317
- New version

* Fri Dec 13 2013 dmorgan <dmorgan> 3.13-1.mga4
+ Revision: 556564
- New version

  + umeabot <umeabot>
    - Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 3.11.1-2.mga3
+ Revision: 386568
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Sep 12 2012 dmorgan <dmorgan> 3.11.1-1.mga3
+ Revision: 293153
- New version

* Thu Sep 22 2011 gil <gil> 3.7-9.mga2
+ Revision: 146742
- rebuilt with spring2 support (added new modules: classloader spring maven-xbean-plugin)

* Wed Jul 20 2011 dmorgan <dmorgan> 3.7-8.mga2
+ Revision: 127124
- Remove unused hack

  + gil <gil>
    - add patch1
    - add patch1

* Thu Apr 28 2011 dmorgan <dmorgan> 3.7-7.mga1
+ Revision: 93151
- Rebuild after bootstrapping
- imported package xbean


* Fri Mar  4 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.7-6
- Add comment for removing javadoc
- Fix maven 3 build

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Dec  6 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.7-4
- Fix pom filename (Resolves rhbz#655827)
- Add depmap for main pom file
- Fixes according to new guidelines (versionless jars, javadocs)

* Fri Jul 30 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.7-3
- Use javadoc:aggregate to generate javadocs

* Fri Jul  9 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.7-2
- Add license to javadoc subpackage

* Mon Jun 21 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.7-1
- First release

